# Example directories
Check out more examples in the above directories.

## Get Started tutorial
Download the tutorial:
```bash
git clone https://github.com/marcomusy/vedo.git
cd vedo/examples
python tutorial.py
```

## Run any of the built-in examples with command:
`vedo --list`

and

`vedo -ir covid19.py`



